import glob
import json

class Main:
	def __init__(self):
		self.project = "edsort"
		self.headers = {
			'en': '.Language=English,English',
			'pl': '.Language=Polish,Polish (Polski)',
			'ru': '.Language=Russian,Russian (Русский)',
		}
		self.translations = {}
		fnames = glob.glob('i18n/*.json')
		for fname in fnames:
			with open(fname, 'rt') as fp:
				data = json.loads(fp.read())
				del data['_']
				self.translations[fname.split('/')[1].split('.')[0]] = data

	def save(self):
		for lang in self.translations.keys():
			with open(f'configs/plug/{self.project}_{lang}.lng', 'wt') as fp:
				fp.write(f'{self.headers[lang]}\n')
				data = self.translations[lang]
				for key in sorted(data.keys()):
					fp.write(f'"{data[key]}"\n')
		with open('src/i18nindex.h', 'wt') as fp:
			fp.write('#define I18N(x) _PSI.GetMsg(_PSI.ModuleNumber, static_cast<int>(x))\n\n')
			fp.write('enum i18n_index {\n')
			data = self.translations[list(self.translations.keys())[0]]
			for key in sorted(data.keys()):
				fp.write(f'{key},\n')
			fp.write('};\n')

def main():
	cls = Main()
	cls.save()

main()
	


import json

class Main:
	def __init__(self, fname, lng):
		with open("src/string_rc.h", 'rt') as fp:
			data = fp.read()
		data = data[data.find('{')+1:]
		data = data[:data.find('}')]
		data = data.split(',')
		index = []
		for line in data:
			line = line.strip()
			if line:
				index.append(line)

		self.index = index
		self.data = {}
		self.lng = lng
		with open(fname, 'rt') as fp:
			self.lines = fp.readlines()

	def convert(self):
		i = 0
		for line in self.lines:
			line = line.strip()
			if line and line[0] == '"':
				self.data[self.index[i]] = line[1:-1]
				i += 1
		assert len(self.index) == i

	def save(self):
		with open(f'i18n/{self.lng}.json', 'wt') as fp:
			fp.write('{\n')
			for key in sorted(self.index):
				fp.write(f'    "{key}": "{self.data[key]}",\n')
			fp.write(f'    "_": "_"\n')
			fp.write('}\n')

def main():
	import sys
	cls = Main(sys.argv[1], sys.argv[2])
	cls.convert()
	cls.save()

main()
	